MethodChannelFlutterDesktopScanner class

An implementation of FlutterDesktopScannerPlatform that uses method channels.

Inheritance

Properties

getDevicesEventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanEventChannel → EventChannel
final

Methods

getDevicesStream() → Stream<List<Scanner>>
override
getPlatformVersion() → Future<String?>
override
imageReprStream() → Stream<Image?>
override
initGetDevices() → Future<bool>
override
initScan(Scanner scanner) → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rawBytesStream() → Stream<Uint8List?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited