FlutterDesktopScannerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterDesktopScannerPlatform
Implementers

Constructors

FlutterDesktopScannerPlatform()
Constructs a FlutterDesktopScannerPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDevicesStream() → Stream<List<Scanner>>
getPlatformVersion() → Future<String?>
imageReprStream() → Stream<Image?>
initGetDevices() → Future<bool>
initScan(Scanner scanner) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rawBytesStream() → Stream<Uint8List?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterDesktopScannerPlatform
The default instance of FlutterDesktopScannerPlatform to use.
getter/setter pair